@@ -3,7 +3,7 @@
 
 #include "link-includes.h"
 
-
+/* Invariant: Leaf if child==NULL */
 typedef struct CNode_s CNode;
 struct CNode_s {
   char  * label;
@@ -14,6 +14,6 @@ struct CNode_s {
 
 CNode * linkage_constituent_tree(Linkage linkage);
 void    linkage_free_constituent_tree(CNode * n);
-char *  linkage_print_constituent_tree(Linkage linkage, int indent);
+char *  linkage_print_constituent_tree(Linkage linkage, int mode);
 
 #endif
