@@ -428,29 +428,45 @@ static int guessed_string(Sentence sent, int i, char * s, char * type) {
     char *t, *u;
     char str[MAX_WORD+1];
     if (boolean_dictionary_lookup(sent->dict, type)) {
-	sent->word[i].x = build_word_expressions(sent, type);
-	for (e = sent->word[i].x; e != NULL; e = e->next) {
+      sent->word[i].x = build_word_expressions(sent, type);
+      e = sent->word[i].x;
 	  if(is_s_word(s)) {
-	    sprintf(str, "%.50s[!].s", s);
+
+	    for (; e != NULL; e = e->next) {
+	      t = strchr(e->string, '.');
+	      if (t != NULL) {
+		sprintf(str, "%.50s[!].%.5s", s, t+1);
+	      } else {
+		sprintf(str, "%.50s[!]", s);
+	      }
+	      t = (char *) xalloc(strlen(str)+1);
+	      strcpy(t,str);
+	      u = string_set_add(t, sent->string_set);
+	      xfree(t, strlen(str)+1);
+	      e->string = u;
+	    }
 	  }
-	  else if(is_ed_word(s)) {
-	    sprintf(str, "%.50s[!].d", s);
+
+	  else {
+	    if(is_ed_word(s)) {
+	      sprintf(str, "%.50s[!].v", s);
+	    }
+	    else if(is_ing_word(s)) {
+	      sprintf(str, "%.50s[!].g", s);
+	    }
+	    else if(is_ly_word(s)) {
+	      sprintf(str, "%.50s[!].e", s);
+	    }
+	    else sprintf(str, "%.50s[!]", s);
+
+	    t = (char *) xalloc(strlen(str)+1);
+	    strcpy(t,str);
+	    u = string_set_add(t, sent->string_set);
+	    xfree(t, strlen(str)+1);
+	    e->string = u;
 	  }
-	  else if(is_ing_word(s)) {
-	    sprintf(str, "%.50s[!].g", s);
-	  }
-	  else if(is_ly_word(s)) {
-	    sprintf(str, "%.50s[!].e", s);
-	  }
-	  else sprintf(str, "%.50s[!]", s);
-	
-	  t = (char *) xalloc(strlen(str)+1);
-	  strcpy(t,str);
-	  u = string_set_add(t, sent->string_set);
-	  xfree(t, strlen(str)+1);
-	  e->string = u;
-	}
-	return TRUE;
+	  return TRUE;
+
     } else {
 	lperror(BUILDEXPR, ".\n To process this sentence your dictionary "
 		"needs the word \"%s\".\n", type);
