@@ -1,5 +1,5 @@
-#include "../../link-4.0/include/link-includes.h"
-#include "../../link-4.0/include/command-line.h"
+#include "../../link-4.1/include/link-includes.h"
+#include "../../link-4.1/include/command-line.h"
 #include "alink.h"
 #include "translator.h"
 
@@ -32,28 +32,28 @@ int main()
     Alinkset * out_alinkset, * in_alinkset;    
     int question_type;
 
-    localv = 3;
+    localv = 1;
 
     translator_strings = string_set_create();
 
     opts  = parse_options_create();
 
-    e_dict  = dictionary_create("/afs/cs/project/link-8/link-4.0/data/4.0.dict", "4.0.knowledge", "4.0.constituent-knowledge", "4.0.affix"); 
+    e_dict  = dictionary_create("../link-4.1/data/4.0.dict", "4.0.knowledge", "4.0.constituent-knowledge", "4.0.affix"); 
     if (e_dict == NULL) {
 	fprintf(stderr, "%s\n", lperrmsg);
 	exit(-1);
     }
-    g_dict  = dictionary_create("/afs/cs/project/link-8/translator/data/german.dict", NULL, NULL, "/afs/cs/project/link-8/translator/data/german.affix"); 
+    g_dict  = dictionary_create("data/german.dict", NULL, NULL, "data/german.affix"); 
     if (g_dict == NULL) {
 	fprintf(stderr, "%s\n", lperrmsg);
 	exit(-1);
     }
-    e_table  = dictionary_create("/afs/cs/project/link-8/translator/data/e_table", NULL, NULL, NULL); 
+    e_table  = dictionary_create("data/e_table", NULL, NULL, NULL); 
     if (e_table == NULL) {
 	fprintf(stderr, "%s\n", lperrmsg);
 	exit(-1);
     }
-    g_table  = dictionary_create("/afs/cs/project/link-8/translator/data/g_table", NULL, NULL, NULL); 
+    g_table  = dictionary_create("data/g_table", NULL, NULL, NULL); 
     if (g_table == NULL) {
 	fprintf(stderr, "%s\n", lperrmsg);
 	exit(-1);
@@ -666,6 +666,7 @@ Alink * replace_words_dumbly(Dictionary e_table, Dictionary g_table, Alink * ali
 	  }
 	  nalink->right = tword[al->rightsub].gstring;
 	  nalink->rightsub = al->rightsub;
+	  nalink->ignore = 0;
 	  nalink->next = front_alink;
 	  front_alink = nalink;
 	}
